<?php

namespace XF2SEO\SEOPackage;

use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

class App
{
    const RELATION_METADATA = 'SEOPackageMetadata';

    const TEXT_PLACEHOLDER = "\0_TEXT_PLACEHOLDER_\0";
    const RENDER_OPTION_KEYWORDS = 'SEOPackage_keywords';

    public static function getContentTypeId(Entity $entity): array
    {
        /** @var mixed $callable */
        $callable = [$entity, 'getSEOPackageContentType'];
        if (is_callable($callable)) {
            $contentType = call_user_func($callable);
        } else {
            $contentType = $entity->getEntityContentType();
        }

        if (strlen($contentType) === 0) {
            throw new \LogicException('Entity must have contentType or implement method `getSEOPackageContentType`');
        }

        return [
            $contentType,
            (int) $entity->getEntityId()
        ];
    }

    public static function setupStructure(Structure &$structure): void
    {
        $structure->relations[self::RELATION_METADATA] = [
            'type' => Entity::TO_ONE,
            'entity' => 'XF2SEO\SEOPackage:Metadata',
            'conditions' => [
                ['content_type', '=', $structure->contentType],
                ['content_id', '=', '$' . $structure->primaryKey]
            ]
        ];
    }
}
